"""add metadata attributes

Revision ID: 26134e26286
Revises: 213b486db87
Create Date: 2014-06-27 05:21:34.613857

"""

# revision identifiers, used by Alembic.
revision = '26134e26286'
down_revision = '213b486db87'

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('episode', sa.Column('metadata_failures', sa.Integer(),
                                       nullable=True, server_default='0'))
    op.add_column('episode', sa.Column('metadata_fetched', sa.Boolean(),
                                       nullable=True, server_default='0'))
    op.add_column('episode', sa.Column('overview', sa.String(), nullable=True,
                                       server_default=''))
    op.add_column('season', sa.Column('metadata_failures', sa.Integer(),
                                      nullable=True, server_default='0'))
    op.add_column('season', sa.Column('metadata_fetched', sa.Boolean(),
                                      nullable=True, server_default='0'))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('season', 'metadata_fetched')
    op.drop_column('season', 'metadata_failures')
    op.drop_column('episode', 'overview')
    op.drop_column('episode', 'metadata_fetched')
    op.drop_column('episode', 'metadata_failures')
    ### end Alembic commands ###
