"""add ReleaseMonitor._resolutions

Revision ID: a49797d68d62
Revises: 566cc0cdd00a
Create Date: 2016-05-30 20:33:37.764631

"""

# revision identifiers, used by Alembic.
revision = 'a49797d68d62'
down_revision = '566cc0cdd00a'

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('release_monitor', sa.Column('_resolutions', sa.String(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('release_monitor', sa.Column('torrent_cached', sa.BOOLEAN(), nullable=True))
    ### end Alembic commands ###
